@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -53,6 +53,12 @@ has outfile => (
 );
 
 
+has type => (
+    is      => 'rw',
+    default => sub { 'png' },
+);
+
+
 has font => (
     is      => 'ro',
     default => sub { '/opt/X11/share/fonts/TTF/VeraMono.ttf' },
@@ -214,9 +220,8 @@ sub draw {
     );
 
     # Output the image
-    my $type = 'png';
-    my $name = $self->outfile . '.' . $type;
-    $i->write( type => $type, file => $name )
+    my $name = $self->outfile . '.' . $self->type;
+    $i->write( type => $self->type, file => $name )
         or die "Can't save $name: ", $i->errstr;
 }
 
@@ -239,7 +244,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0302
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -265,6 +270,7 @@ version 0.0302
     outfile  => 'ukulele-chord',
     font     => '/path/to/TTF/font.ttf',
     tuning   => [qw/A E C G/],
+    type     => 'bmp',
     verbose  => 1,
   );
   $dia->draw;
@@ -274,9 +280,6 @@ version 0.0302
 A C<Music::FretboardDiagram> object draws fretboard chord diagrams including
 neck position and chord name annotations for guitar, ukulele, banjo, etc.
 
-This module outputs PNG image files only.  So for instance, on Linux and Macs
-you will need the libpng-dev library.
-
 =for html <br><img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/chord-diagram.png"><br>
 
 =head1 ATTRIBUTES
@@ -355,10 +358,18 @@ Default: 30
   $dia->outfile('chord-042');
   $outfile = $dia->outfile;
 
-The image file name minus the (PNG) extension.
+The image file name minus the extension.
 
 Default: chord-diagram
 
+=head2 type
+
+  $type = $dia->type;
+
+The image file extension.
+
+Default: png
+
 =head2 font
 
   $font = $dia->font;
@@ -406,8 +417,7 @@ Construct the B<fretboard> attribute from the B<tuning>.
 
   $dia->draw;
 
-Render the requested chord diagram as a C<PNG> image.  (Other formats are not
-supported.)
+Render the requested chord diagram as an image file of B<type>.
 
 =head1 SEE ALSO
 
